@@ -120,7 +120,8 @@ void StarArray::Read(std::ifstream &input)
 
       // If it passes all the filters and is a singleton, primary, or
       //  sufficiently far from its primary, put it into the STL vector.
-      if ((tempstar.GetStarPrimaryDistance() == 0.0)
+      if (! ArrayRules.ChartHideCompanions
+	  || (tempstar.GetStarPrimaryDistance() == 0.0)
 	  || ((tempstar.GetStarPrimaryDistance() * (200 /*pixels*/) 
 	       / ArrayRules.ChartRadius) > MIN_SECONDARY_DISTANCE))
 	Array.push_back(tempstar);
@@ -348,7 +349,6 @@ bool StarArray::SetRules(const Rules &rules, changetype_t ruleschange)
       //  (return with an error if none of the file(s) can be read)
       {
 	size_t numValidFiles = 0;
-	std::ifstream data;
 
 	TotalStars = 0;
 	Array.clear();
@@ -356,6 +356,7 @@ bool StarArray::SetRules(const Rules &rules, changetype_t ruleschange)
 	Array.reserve(100);
 
 	citerate (StringList, ArrayRules.ChartFileNames, i) {
+	  std::ifstream data;
 	  data.open((*i).c_str());
 	  if (data.good()) {
 	    Read(data);
@@ -376,7 +377,7 @@ bool StarArray::SetRules(const Rules &rules, changetype_t ruleschange)
       Sort();
       // fall through...
 
-    case DECORATIONS_CHANGE: // search for brightest 5 stars, if necessary
+    case DECORATIONS_CHANGE: // search for brightest 8 stars, if necessary
       if (ArrayRules.StarLabels == LANDMARK_LABEL) {
 
 	if (Array.size() <= DISPLAY_N_STARS)
@@ -512,7 +513,10 @@ void StarArray::drawgridequator(StarViewer *sv, unsigned int wincenterX,
   sv->setcolor(POSITIVE);
   if (ArrayRules.CelestialCoords)
     for (unsigned int i = 0; i < 4; i++)
-      gridlabels.push_back(starstrings::itoa(6 * i) + "h");
+      gridlabels.push_back(starstrings::itoa(6 * i) + 
+	  /* TRANSLATORS: This is the abbreviation for
+	     "hours of right ascension". */
+	  _("h"));
   else
     for (unsigned int i = 0; i < 4; i++)
       gridlabels.push_back(starstrings::itoa(90 * i) + DEGREE_UTF8);
@@ -561,26 +565,46 @@ void StarArray::drawlegend(StarViewer *sv) const
     
   // first draw the chart information in the upper left
   if (ArrayRules.CelestialCoords) {
-    sra = "R.A. ";
-    sdec = "Dec ";
+    sra = 
+      /* TRANSLATORS: This is the abbreviation for "right ascension." */
+      string(_("R.A.")) + " ";
+    sdec =
+      /* TRANSLATORS: This is the abbreviation for "declination." */
+      string(_("Dec.")) + " ";
   }
   else {
-    sra = "Long ";
-    sdec = "Lat ";
+    sra =
+      /* TRANSLATORS: This is the abbreviation for "longitude". */
+      string(_("Long.")) + " ";
+    sdec =
+      /* TRANSLATORS: This is the abbreviation for "latitude". */
+      string(_("Lat.")) + " ";
   }
   SolidAngle gridposn = ArrayRules.ChartLocation.toSpherical();
   sra += starstrings::ra_to_str(gridposn.getPhi(), ' ',
 				ArrayRules.CelestialCoords, true);
   sdec += starstrings::dec_to_str(gridposn.getTheta(), ' ', true);
-  sdist = starstrings::ftoa(ArrayRules.ChartLocation.magnitude(), 5) +
-	  " LY from Earth";
-  srad = "Chart Radius: " + starstrings::ftoa(ArrayRules.ChartRadius, 5)+" LY";
-  sdmag = "Dim Mag: " + starstrings::ftoa(ArrayRules.ChartDimmestMagnitude, 4);
-  sbmag="Bright Mag: "+starstrings::ftoa(ArrayRules.ChartBrightestMagnitude,4);
+  sdist = starstrings::ftoa(ArrayRules.ChartLocation.magnitude(), 5) + " " +
+	  /* TRANSLATORS: "LY" is the abbreviation for "light-years". */
+	  _("LY from Earth");
+  srad = string(_("Chart Radius")) + ": " +
+	  starstrings::ftoa(ArrayRules.ChartRadius, 5) + " " +
+	  /* TRANSLATORS: "LY" is the abbreviation for "light-years". */
+	  _("LY");
+  sdmag = 
+	  /* TRANSLATORS: "Mag" is the abbreviation for "magnitude",
+	     the astronomical brightness of an object. */
+	  string(_("Dim Mag")) + ": " +
+          starstrings::ftoa(ArrayRules.ChartDimmestMagnitude, 4);
+  sbmag =
+	  /* TRANSLATORS: "Mag" is the abbreviation for "magnitude",
+	     the astronomical brightness of an object. */
+	  string(_("Bright Mag")) + ": " +
+	  starstrings::ftoa(ArrayRules.ChartBrightestMagnitude, 4);
   
-  sv->setcolor(BOLD_COLOR); sv->drawtext("CHART STATUS", 15, ybase += 15);
+  sv->setcolor(BOLD_COLOR); sv->drawtext(_("CHART STATUS"), 15, ybase += 15);
   sv->setcolor(LABEL_COLOR);
-  sv->drawtext("Location of Chart Origin:", 5, ybase += 15);
+  sv->drawtext(_("Location of Chart Origin:"), 5, ybase += 15);
   if (ArrayRules.ChartLocation.magnitude() > 0.0) {
     sv->drawtext(sra, 10, ybase += 15);
     sv->drawtext(sdec, 10, ybase += 15);
@@ -601,20 +625,22 @@ void StarArray::drawlegend(StarViewer *sv) const
   //  classes are currently turned on) in the upper right
   
   xbase = (sv->width() > 100) ? sv->width() - 95 : 5;
-  sv->setcolor(BOLD_COLOR); sv->drawtext("LEGEND", xbase + 5, 15);
+  sv->setcolor(BOLD_COLOR); sv->drawtext(_("LEGEND"), xbase + 5, 15);
 
 #define LO LEGEND_OFFSETS
 
   drawlegenditem(sv, WOLF_RAYET_COLOR, 0, 
-		 xbase + LO[10][0], LO[10][1], 5, "Wolf-Rayet");
+		 xbase + LO[10][0], LO[10][1], 5,
+	    /* TRANSLATORS: "Wolf-Rayet" is a proper name of a type of star. */
+		 _("Wolf-Rayet"));
   for (unsigned int i = 0; i < 7; i++)
     drawlegenditem(sv, CLASS_COLORS[i], i, xbase + LO[i][0], LO[i][1], 5,
 		   string() + SpecClass::int_to_class(i));
   drawlegenditem(sv, D_COLOR, 7, xbase + LO[7][0], LO[7][1], 3, "wd");
   drawlegenditem(sv, DEFAULT_COLOR, 8, xbase + LO[8][0], LO[8][1], 5,
-		 "Unknown", -85, 5);
+		 _("Unknown"), -85, 5);
   drawlegenditem(sv, NON_STELLAR_COLOR, 9, xbase + LO[9][0], LO[9][1], 5,
-		 "Non-stellar", -85, 5);
+		 _("Non-stellar"), -85, 5);
   return;
 }
 
@@ -690,7 +716,6 @@ void StarArray::Diagram(StarViewer *sv, double brightmag, double dimmag) const
   int width, height;
   double magscale = dimmag - brightmag;
   int scaling = (magscale < 0) ? -1 : 1;
-  char *maglabel = "MAGNITUDE";
 
   // if dimmag < brightmag, this will flip the vertical axis
   if (magscale < 0) 
@@ -783,13 +808,18 @@ void StarArray::Diagram(StarViewer *sv, double brightmag, double dimmag) const
 
   // Draw axis titles.
   sv->setcolor(BOLD_COLOR);
-  sv->drawtext("SPECTRAL CLASS", 60 + width / 2 - 50, height + 50);
+  sv->drawtext(_("SPECTRAL CLASS"), 60 + width / 2 - 50, height + 50);
 
   if (magscale == 0.0) sv->setcolor(ERROR_COLOR);
-  for (unsigned int posn = 0; posn < strlen(maglabel); posn++) {
-    int y = height / 2 - 60 + 16 * posn;
-    sv->drawtext(maglabel[posn], 10, y);
-  }
+  sv->drawtext_vertical(_(
+    /* TRANSLATORS: "MAGNITUDE" refers to the astronomical brightness
+       of an object. */
+    "MAGNITUDE"), 10, height / 2 - 60);
+      
+  //for (unsigned int posn = 0; posn < strlen(maglabel); posn++) {
+  //  int y = height / 2 - 60 + 16 * posn;
+  //  sv->drawtext(maglabel[posn], 10, y);
+  //}
 
   return;
 }
