@@ -26,6 +26,8 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <unistd.h>
+#include <string.h> // for strdup()
+#include <cstdlib>  // for free()
 #include <map>
 
 #include "starplot.h"
@@ -38,13 +40,13 @@ GtkItemFactoryEntry menu_items[] = {
 };
 
 GtkWidget *options_toggle_widgets[OPTIONS_TOGGLE_MENU_SIZE];
-char options_toggle_names[OPTIONS_TOGGLE_MENU_SIZE][50];
+char options_toggle_names[OPTIONS_TOGGLE_MENU_SIZE][100];
 GtkWidget *options_label_widgets[OPTIONS_LABEL_MENU_SIZE];
-char options_label_names[OPTIONS_LABEL_MENU_SIZE][50];
+char options_label_names[OPTIONS_LABEL_MENU_SIZE][100];
 GtkWidget *options_diameter_widgets[OPTIONS_DIAMETER_MENU_SIZE];
-char options_diameter_names[OPTIONS_DIAMETER_MENU_SIZE][50];
+char options_diameter_names[OPTIONS_DIAMETER_MENU_SIZE][100];
 GtkWidget *options_coord_widgets[OPTIONS_COORD_MENU_SIZE];
-char options_coord_names[OPTIONS_COORD_MENU_SIZE][50];
+char options_coord_names[OPTIONS_COORD_MENU_SIZE][100];
 
 
 /* set_menu_globals(): A boring function to set all the arrays of menu item
@@ -55,28 +57,28 @@ void set_menu_globals (GtkItemFactory *item_factory)
   unsigned int i;
   GtkWidget *item = 0;
 
-  strcpy(options_toggle_names[TOGGLE_BARS], "/Options/Toggle Bars");
-  strcpy(options_toggle_names[TOGGLE_GRID], "/Options/Toggle Grid");
-  strcpy(options_toggle_names[TOGGLE_LEGEND], "/Options/Toggle Legend");
+  strcpy(options_toggle_names[TOGGLE_BARS], _("/Options/Toggle Bars"));
+  strcpy(options_toggle_names[TOGGLE_GRID], _("/Options/Toggle Grid"));
+  strcpy(options_toggle_names[TOGGLE_LEGEND], _("/Options/Toggle Legend"));
 
   strcpy(options_label_names[(int)LANDMARK_LABEL],
-	 "/Options/Star Labels/Landmark Stars");
+	 _("/Options/Star Labels/Landmark Stars"));
   strcpy(options_label_names[(int)STRING_LABEL],
-	 "/Options/Star Labels/All Star Names");
+	 _("/Options/Star Labels/All Star Names"));
   strcpy(options_label_names[(int)NUMBER_LABEL],
-	 "/Options/Star Labels/Numerical Index");
+	 _("/Options/Star Labels/Numerical Index"));
   strcpy(options_label_names[(int)NO_LABEL],
-	 "/Options/Star Labels/Labels Off");
+	 _("/Options/Star Labels/Labels Off"));
 
   strcpy(options_diameter_names[(int)MAGNITUDE_DIAMETERS],
-	 "/Options/Star Diameters/By Magnitude");
+	 _("/Options/Star Diameters/By Magnitude"));
   strcpy(options_diameter_names[(int)MK_DIAMETERS],
-	 "/Options/Star Diameters/By MK Class");
+	 _("/Options/Star Diameters/By MK Class"));
 
   strcpy(options_coord_names[CELESTIAL], 
-	 "/Options/Coordinate System/Celestial");
+	 _("/Options/Coordinate System/Celestial"));
   strcpy(options_coord_names[GALACTIC],
-	 "/Options/Coordinate System/Galactic");
+	 _("/Options/Coordinate System/Galactic"));
 
   /* The following code sets the check buttons in the Options menu to be
      toggled ON by default, matching the initial state of the program.
@@ -115,7 +117,14 @@ void my_gtk_main_menu (GtkWidget *window, GtkWidget **menubar)
 {
   GtkItemFactory *item_factory;
   GtkAccelGroup *accel_group;
-  gint nmenu_items = sizeof (menu_items) / sizeof (menu_items[0]);
+  int nmenu_items = sizeof (menu_items) / sizeof (menu_items[0]);
+ 
+  /* Gettextize the menu item names */
+  for (int i = 0; i < nmenu_items; i++) {
+    menu_items[i].path = strdup(gettext(menu_items[i].path));
+    if (menu_items[i].item_type[0] != 0 && menu_items[i].item_type[0] != '<')
+      menu_items[i].item_type = strdup(gettext(menu_items[i].item_type));
+  }
   
   accel_group = gtk_accel_group_new ();
        
@@ -165,7 +174,7 @@ void my_gtk_button_bar(GtkWidget **OK_btn, GtkWidget **defaults_btn,
   gtk_container_add (GTK_CONTAINER (buttonbox), *OK_btn);
   gtk_widget_show(*OK_btn);
   
-  *defaults_btn = gtk_button_new_with_mnemonic ("_Defaults");
+  *defaults_btn = gtk_button_new_from_stock (GTK_STOCK_REVERT_TO_SAVED);
   gtk_container_add (GTK_CONTAINER (buttonbox), *defaults_btn);
   gtk_widget_show(*defaults_btn);
   
@@ -436,21 +445,21 @@ void my_gtk_push_buttons (GtkWidget *window, GtkWidget **buttonbar)
 
   // and set some popup help tips
   tooltips = gtk_tooltips_new ();
-  gtk_tooltips_set_tip (tooltips, buttons[0], "Open star database...", 0);
-  gtk_tooltips_set_tip (tooltips, buttons[1], "Zoom in", 0);
-  gtk_tooltips_set_tip (tooltips, buttons[2], "Zoom out", 0);
+  gtk_tooltips_set_tip (tooltips, buttons[0], _("Open star database..."), 0);
+  gtk_tooltips_set_tip (tooltips, buttons[1], _("Zoom in"), 0);
+  gtk_tooltips_set_tip (tooltips, buttons[2], _("Zoom out"), 0);
   gtk_tooltips_set_tip (tooltips, buttons[3],
-			"Rotate chart clockwise about its axis", 0);
+			_("Rotate chart clockwise about its axis"), 0);
   gtk_tooltips_set_tip (tooltips, buttons[4], 
-			"Rotate chart counterclockwise about its axis", 0);
+			_("Rotate chart counterclockwise about its axis"), 0);
   gtk_tooltips_set_tip (tooltips, buttons[5], 
-			"Tilt chart north pole towards you", 0);
+			_("Tilt chart north pole towards you"), 0);
   gtk_tooltips_set_tip (tooltips, buttons[6], 
-			"Tilt chart south pole towards you", 0);
+			_("Tilt chart south pole towards you"), 0);
   gtk_tooltips_set_tip (tooltips, buttons[7], 
-			"Decrease magnitude limit (Show fewer stars)", 0);
+			_("Decrease magnitude limit (Show fewer stars)"), 0);
   gtk_tooltips_set_tip (tooltips, buttons[8], 
-			"Increase magnitude limit (Show more stars)", 0);
+			_("Increase magnitude limit (Show more stars)"), 0);
   return;
 }
 
@@ -458,39 +467,44 @@ void my_gtk_push_buttons (GtkWidget *window, GtkWidget **buttonbar)
 /* Silly little "about" dialog */
 void abouthelp()
 {
-  GtkWidget *popup, *OK, *topbox, *label[11];
+  GtkWidget *popup, *OK, *topbox, *textbox, *frame;
+  GtkTextBuffer *text;
   
   popup = gtk_dialog_new ();
   gtk_window_set_policy (GTK_WINDOW (popup), false, false, true);
-  gtk_window_set_title (GTK_WINDOW (popup), "About StarPlot");
+  gtk_window_set_title (GTK_WINDOW (popup), _("About StarPlot"));
   
   topbox = gtk_vbox_new (true, 0);
   gtk_container_set_border_width (GTK_CONTAINER (topbox), 10);
   gtk_widget_show (topbox);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (popup)->vbox), topbox,
 		      true, true, 0);
+ 
+  frame = gtk_frame_new (0);
+  gtk_widget_show (frame);
   
-  label[0] = gtk_label_new ("StarPlot version " STARPLOT_VERSION);
-  label[1] = gtk_label_new ("");
-  label[2] = gtk_label_new ("Copyright " COPYRIGHT_UTF8 " 2000-2003 "
-  			    "Kevin B. McCarty");
-  label[3] = gtk_label_new ("under the GNU General Public License");
-  label[4] = gtk_label_new ("");
-  label[5] = gtk_label_new ("For help, please select Help->Documentation");
-  label[6] = gtk_label_new ("from the menu, or see the HTML documents in");
-  label[7] = gtk_label_new (DOCDIR "/html");
-  label[8] = gtk_label_new ("");
-  label[9] = gtk_label_new ("For additional data files, see the StarPlot web"
-  			    " page:");
-  label[10] = gtk_label_new ("http://starplot.org/");
+  string textstr = string(_("StarPlot version %s\n\n"));
+  textstr += string(_("Copyright %s 2000-2004 Kevin B. McCarty\n"));
+  textstr += string(_("Licensed under the GNU General Public License\n\n"));
+  textstr += string(_(
+"For help, please select Help->Documentation from the menu, or \
+see the HTML documents in %s\n\n"));
+  textstr += string(_("For additional data files, see the StarPlot web page:\n"));
+  textstr += string("http://starplot.org/");
+  textstr = starstrings::ssprintf(textstr.c_str(),
+	    STARPLOT_VERSION, COPYRIGHT_UTF8, DOCDIR "/html");
+  
+  text = gtk_text_buffer_new (0);
+  gtk_text_buffer_set_text (text, textstr.c_str(), textstr.size());
+  textbox = gtk_text_view_new_with_buffer (text);
+  gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (textbox), GTK_WRAP_WORD);
+  gtk_text_view_set_editable (GTK_TEXT_VIEW (textbox), false);
+  gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (textbox), false);
+  gtk_widget_set_usize (textbox, 350, 200);
+  gtk_widget_show (textbox);
 
-  for (unsigned int i = 5; i < 11; i++)
-    gtk_misc_set_alignment (GTK_MISC (label[i]), 0.0F, 0.0F);
-
-  for (unsigned int i = 0; i < 11; i++) {
-    gtk_box_pack_start (GTK_BOX (topbox), label[i], true, true, 0);
-    gtk_widget_show (label[i]);
-  }
+  gtk_container_add (GTK_CONTAINER (frame), textbox);
+  gtk_box_pack_start (GTK_BOX (topbox), frame, true, true, 0);
 
   my_gtk_popup_button (&OK,  GTK_DIALOG (popup)->action_area, popup);
   gtk_window_set_focus (GTK_WINDOW (popup), OK);
@@ -502,8 +516,16 @@ void abouthelp()
    with the other file selection dialogs. */
 
 
+static void openurl(char * url);
+
 /* helpdocs(): Read help documentation */
 void helpdocs()
+{ openurl("file://" DOCDIR "/html/index.html"); }
+
+void webpage()
+{ openurl("http://www.starplot.org/"); }
+
+void openurl(char * url)
 {
   pid_t pid;
   if (starstrings::isempty(globals::program_help_browser)) {
@@ -513,8 +535,7 @@ void helpdocs()
 
   char * temp = new char[globals::program_help_browser.size() + 1];
   std::strcpy(temp, globals::program_help_browser.c_str());
-  char * const command[3] = 
-    { temp, "file://" DOCDIR "/html/index.html", NULL };
+  char * const command[3] = { temp, url, NULL };
 
   pid = fork();
 
